# Ultralytics HUB-SDK 🚀, AGPL-3.0 License

from hub_sdk.config import HUB_API_ROOT, HUB_WEB_ROOT
from hub_sdk.hub_client import HUBClient

__version__ = "0.0.17"
__all__ = "__version__", "HUBClient", "HUB_API_ROOT", "HUB_WEB_ROOT"
